<?php
/**
* @package		PayPlans
* @copyright	Copyright (C) 2010 - 2018 Stack Ideas Sdn Bhd. All rights reserved.
* @license		GNU/GPL, see LICENSE.php
* PayPlans is free software. This version may have been modified pursuant
* to the GNU General Public License, and as distributed it includes or
* is derivative of works licensed under the GNU General Public License or
* other free or open source software licenses.
* See COPYRIGHT.php for copyright notices and details.
*/
defined('_JEXEC') or die('Unauthorized Access');

require_once(__DIR__ . '/controller.php');

class PayplansControllerInstallSync extends PayplansSetupController
{
	/**
	 * Synchronizes database tables
	 *
	 * @since	4.2.0
	 * @access	public
	 */
	public function execute()
	{
		// Load foundry
		$this->engine();

		// Get this installation version
		$version = $this->getInstalledVersion();

		// Get previous version installed
		$previous = $this->getPreviousVersion('db_version');

		$affected = '';
		if ($previous !== false) {

			// lets run the db scripts sync if needed.
			$db = PP::db();
			$affected = $db->sync($previous);
		}

		// Update the version in the database to the latest now
		$config = PP::table('Config');
		$config->load(array('key' => 'db_version'));
		$config->key = 'db_version';
		$config->value = $version;

		// Save the configuration
		$config->store($config->key);

		// If the previous version is empty, we can skip this altogether as we know this is a fresh installation
		$message = JText::sprintf('COM_PP_INSTALLATION_MAINTENANCE_DB_NOTHING_TO_SYNC', $version);

		if (!empty($affected)) {
			$message = JText::sprintf('COM_PP_INSTALLATION_MAINTENANCE_DB_SYNCED', $version);
		}

		$this->setInfo($message);

		return $this->output();
	}
}
